==> eiffelstudio-18.01.10.1424.tar: F_code/C6/de285.c <==
/*
 * Code for class DEBUGGED_OBJECT_MANAGER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "de285.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {DEBUGGED_OBJECT_MANAGER}.make */
void F306_5767 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTEAA("make", 305, Current, 0, 1, 5946);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	tb1 = F6192_82661(RTCW(arg1));
	if (tb1) {
		RTHOOK(3);
		F306_5769(Current);
	}
	RTHOOK(4);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {DEBUGGED_OBJECT_MANAGER}.reset */
void F306_5768 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("reset", 305, Current, 0, 0, 5947);
	RTHOOK(1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) NULL;
	RTHOOK(2);
	RTEE;
}

/* {DEBUGGED_OBJECT_MANAGER}.set_dotnet_system */
void F306_5769 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_dotnet_system", 305, Current, 0, 0, 5948);
	RTHOOK(1);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(2);
	RTEE;
}

/* {DEBUGGED_OBJECT_MANAGER}.class_type_at_address */
EIF_REFERENCE F306_5770 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTEAA("class_type_at_address", 305, Current, 1, 1, 5949);
	RTGC;
	RTHOOK(1);
	loc1 = F306_5785(Current, arg1, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L));
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_2_);
	RTHOOK(3);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) tr1;
}

/* {DEBUGGED_OBJECT_MANAGER}.object_at_address */
EIF_REFERENCE F306_5772 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("object_at_address", 305, Current, 0, 1, 5951);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_REFERENCE) F306_5785(Current, arg1, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L));
}

/* {DEBUGGED_OBJECT_MANAGER}.attributes_at_address */
EIF_REFERENCE F306_5773 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTEAA("attributes_at_address", 305, Current, 1, 3, 5952);
	RTGC;
	RTHOOK(1);
	loc1 = F306_5785(Current, arg1, arg2, arg3);
	RTHOOK(2);
	tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R43386[Dtype(loc1)-4639])(RTCW(loc1));
	RTHOOK(3);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) tr1;
}

/* {DEBUGGED_OBJECT_MANAGER}.sorted_attributes_at_address */
EIF_REFERENCE F306_5774 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTEAA("sorted_attributes_at_address", 305, Current, 1, 3, 5953);
	RTGC;
	RTHOOK(1);
	loc1 = F306_5785(Current, arg1, arg2, arg3);
	RTHOOK(2);
	tr1 = F4639_54485(RTCW(loc1));
	RTHOOK(3);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) tr1;
}

/* {DEBUGGED_OBJECT_MANAGER}.special_object_count_and_capacity_at_address */
EIF_REFERENCE F306_5776 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,Result);
	RTLIU(5);
	
	RTEAA("special_object_count_and_capacity_at_address", 305, Current, 1, 1, 5955);
	RTGC;
	RTHOOK(1);
	loc1 = F306_5785(Current, arg1, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L));
	RTHOOK(2);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFFF9,2,3831,3848,3848,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNTS(typres0.id, 3, 1);
	}
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1) + O43391[Dtype(loc1)-4638]);
	((EIF_TYPED_VALUE *)tr1+1)->it_i4 = ti4_1;
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1) + O43392[Dtype(loc1)-4638]);
	((EIF_TYPED_VALUE *)tr1+2)->it_i4 = ti4_1;
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	RTLE;
	RTEE;
	return Result;
}

/* {DEBUGGED_OBJECT_MANAGER}.last_debugged_object */
EIF_REFERENCE F306_5777 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {DEBUGGED_OBJECT_MANAGER}.debugger_manager */
EIF_REFERENCE F306_5780 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {DEBUGGED_OBJECT_MANAGER}.is_valid_and_known_object_address */
EIF_BOOLEAN F306_5782 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("is_valid_and_known_object_address", 305, Current, 0, 1, 5961);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + O62972[Dtype(tr1)-6191]);
	Result = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE, EIF_REFERENCE)) R63432[Dtype(tr1)-6204])(RTCW(tr1), arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {DEBUGGED_OBJECT_MANAGER}.classic_debugged_object_with_class */
EIF_REFERENCE F306_5784 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,tr1);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLR(3,Current);
	RTLIU(4);
	
	RTEAA("classic_debugged_object_with_class", 305, Current, 0, 2, 5963);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(4640, 0x00).id, 4640, _OBJSIZ_4_3_1_2_0_0_0_0_);
	F4641_54492(RTCW(tr1), arg1, arg2);
	RTHOOK(2);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) tr1;
}

/* {DEBUGGED_OBJECT_MANAGER}.debugged_object */
EIF_REFERENCE F306_5785 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("debugged_object", 305, Current, 0, 3, 5964);
	RTGC;
	RTHOOK(1);
	tb1 = '\0';
	if ((EIF_BOOLEAN) (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) && (EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current) != NULL))) {
		tr1 = *(EIF_REFERENCE *)(Current);
		tr1 = *(EIF_REFERENCE *)(RTCW(tr1));
		tb1 = RTEQ(tr1, arg1);
	}
	if (tb1) {
		RTHOOK(2);
		Result = *(EIF_REFERENCE *)(Current);
		RTHOOK(3);
		if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_2_0_0_) < arg2) || (EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_2_0_1_) > arg3))) {
			RTHOOK(4);
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32)) R43384[Dtype(Result)-4639])(RTCW(Result), arg2, arg3);
		} else {
			RTHOOK(5);
			if ((EIF_BOOLEAN) ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_2_0_0_) != arg2) || (EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_2_0_1_) != arg3))) {
			}
		}
	} else {
		RTHOOK(6);
		if (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_)) {
			RTHOOK(7);
			tr1 = RTLNS(eif_new_type(4639, 0x00).id, 4639, _OBJSIZ_3_3_1_2_0_0_0_0_);
			Result = (EIF_REFERENCE) tr1;
		} else {
			RTHOOK(8);
			tr1 = RTLNS(eif_new_type(4640, 0x00).id, 4640, _OBJSIZ_4_3_1_2_0_0_0_0_);
			F4641_54491(RTCW(tr1), arg1, arg2, arg3);
			Result = (EIF_REFERENCE) tr1;
		}
	}
	RTHOOK(9);
	RTAR(Current, Result);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) Result;
	RTHOOK(10);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_2_0_0_) = (EIF_INTEGER_32) arg2;
	RTHOOK(11);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_2_0_1_) = (EIF_INTEGER_32) arg3;
	RTHOOK(12);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit285 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-23.09.10.7341.tar: F_code/C6/de285.c <==
/*
 * Code for class DEBUGGED_OBJECT_MANAGER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "de285.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {DEBUGGED_OBJECT_MANAGER}.make */
void F300_5444 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTEAA("make", 299, Current, 0, 1, 4973);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	tb1 = F6813_96339(RTCW(arg1));
	if (tb1) {
		RTHOOK(3);
		F300_5446(Current);
	}
	RTHOOK(4);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {DEBUGGED_OBJECT_MANAGER}.reset */
void F300_5445 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("reset", 299, Current, 0, 0, 4974);
	RTHOOK(1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) NULL;
	RTHOOK(2);
	RTEE;
}

/* {DEBUGGED_OBJECT_MANAGER}.set_dotnet_system */
void F300_5446 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_dotnet_system", 299, Current, 0, 0, 4975);
	RTHOOK(1);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(2);
	RTEE;
}

/* {DEBUGGED_OBJECT_MANAGER}.class_type_at_address */
EIF_REFERENCE F300_5447 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTEAA("class_type_at_address", 299, Current, 1, 1, 4976);
	RTGC;
	RTHOOK(1);
	loc1 = F300_5462(Current, arg1, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L));
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_2_);
	RTHOOK(3);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) tr1;
}

/* {DEBUGGED_OBJECT_MANAGER}.object_at_address */
EIF_REFERENCE F300_5449 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("object_at_address", 299, Current, 0, 1, 4978);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_REFERENCE) F300_5462(Current, arg1, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L));
}

/* {DEBUGGED_OBJECT_MANAGER}.attributes_at_address */
EIF_REFERENCE F300_5450 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTEAA("attributes_at_address", 299, Current, 1, 3, 4979);
	RTGC;
	RTHOOK(1);
	loc1 = F300_5462(Current, arg1, arg2, arg3);
	RTHOOK(2);
	tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R49069[Dtype(RTCW(loc1))-4803])(loc1);
	RTHOOK(3);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) tr1;
}

/* {DEBUGGED_OBJECT_MANAGER}.sorted_attributes_at_address */
EIF_REFERENCE F300_5451 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTEAA("sorted_attributes_at_address", 299, Current, 1, 3, 4980);
	RTGC;
	RTHOOK(1);
	loc1 = F300_5462(Current, arg1, arg2, arg3);
	RTHOOK(2);
	tr1 = F4803_60622(RTCW(loc1));
	RTHOOK(3);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) tr1;
}

/* {DEBUGGED_OBJECT_MANAGER}.special_object_count_and_capacity_at_address */
EIF_REFERENCE F300_5453 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,Result);
	RTLIU(5);
	
	RTEAA("special_object_count_and_capacity_at_address", 299, Current, 1, 1, 4982);
	RTGC;
	RTHOOK(1);
	loc1 = F300_5462(Current, arg1, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L));
	RTHOOK(2);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFFF9,2,3840,4474,4474,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNTS(typres0.id, 3, 1);
	}
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1) + O49074[Dtype(loc1)-4802]);
	((EIF_TYPED_VALUE *)tr1+1)->it_i4 = ti4_1;
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1) + O49075[Dtype(loc1)-4802]);
	((EIF_TYPED_VALUE *)tr1+2)->it_i4 = ti4_1;
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(4);
	RTLE;
	RTEE;
	return Result;
}

/* {DEBUGGED_OBJECT_MANAGER}.is_valid_and_known_object_address */
EIF_BOOLEAN F300_5459 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("is_valid_and_known_object_address", 299, Current, 0, 1, 4969);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + O74072[Dtype(tr1)-6812]);
	Result = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE, EIF_REFERENCE)) R74449[Dtype(RTCW(tr1))-6823])(tr1, arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {DEBUGGED_OBJECT_MANAGER}.classic_debugged_object_with_class */
EIF_REFERENCE F300_5461 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,tr1);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLR(3,Current);
	RTLIU(4);
	
	RTEAA("classic_debugged_object_with_class", 299, Current, 0, 2, 4971);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(4804, 0x00).id, 4804, _OBJSIZ_4_3_1_2_0_0_0_0_);
	F4805_60629(RTCW(tr1), arg1, arg2);
	RTHOOK(2);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) tr1;
}

/* {DEBUGGED_OBJECT_MANAGER}.debugged_object */
EIF_REFERENCE F300_5462 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("debugged_object", 299, Current, 0, 3, 4972);
	RTGC;
	RTHOOK(1);
	tb1 = '\0';
	if ((EIF_BOOLEAN) (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) && (EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current) != NULL))) {
		tr1 = *(EIF_REFERENCE *)(Current);
		tr1 = *(EIF_REFERENCE *)(RTCW(tr1));
		tb1 = RTEQ(tr1, arg1);
	}
	if (tb1) {
		RTHOOK(2);
		Result = *(EIF_REFERENCE *)(Current);
		RTHOOK(3);
		if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_2_0_0_) < arg2) || (EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_2_0_1_) > arg3))) {
			RTHOOK(4);
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32)) R49067[Dtype(RTCW(Result))-4803])(Result, arg2, arg3);
		} else {
			RTHOOK(5);
			if ((EIF_BOOLEAN) ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_2_0_0_) != arg2) || (EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_2_0_1_) != arg3))) {
			}
		}
	} else {
		RTHOOK(6);
		if (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_)) {
			RTHOOK(7);
			Result = RTLNS(eif_new_type(4803, 0x00).id, 4803, _OBJSIZ_3_3_1_2_0_0_0_0_);
		} else {
			RTHOOK(8);
			Result = RTLNS(eif_new_type(4804, 0x00).id, 4804, _OBJSIZ_4_3_1_2_0_0_0_0_);
			F4805_60628(RTCW(Result), arg1, arg2, arg3);
		}
	}
	RTHOOK(9);
	RTAR(Current, Result);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) Result;
	RTHOOK(10);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_2_0_0_) = (EIF_INTEGER_32) arg2;
	RTHOOK(11);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_2_0_1_) = (EIF_INTEGER_32) arg3;
	RTHOOK(13);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit285 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
